@@ -14,7 +14,7 @@
 #include <time.h>
 #include <net/if.h>
 
-#ifdef __OpenBSD__
+#if defined(__OpenBSD__) || defined(__NetBSD__)
 #  include <net/bpf.h>
 #  include <net/if_pppvar.h>
 #  include <net/if_ppp.h>
