@@ -1945,6 +1945,7 @@ new_terminal_cmd (char **cmd, struct terminal_config *cfg_in, gchar *geometry)
 	static char **env_copy;
 	static int winid_pos;
 	char buffer [40];
+	char winclass [64];
 	char *shell, *name;
 	int i = 0;
 	struct terminal_config *cfg;
@@ -2008,7 +2009,8 @@ new_terminal_cmd (char **cmd, struct terminal_config *cfg_in, gchar *geometry)
 	if (cfg->window_title) {
 	  gtk_window_set_title(GTK_WINDOW(app), cfg->window_title);
  	}
-	gtk_window_set_wmclass (GTK_WINDOW (app), "GnomeTerminal", "GnomeTerminal");
+	sprintf(winclass, "GnomeTerminal:%p", app);
+	gtk_window_set_wmclass (GTK_WINDOW (app), "GnomeTerminal", winclass);
 	gtk_window_set_policy(GTK_WINDOW (app), TRUE, TRUE, TRUE);
 
 	if (cmd != NULL)
@@ -2246,7 +2248,13 @@ load_session ()
 
 		g_free(cfg);
 		g_free (geom);
-		g_strfreev (argv);
+		if (i==0) {
+			/* need to save the initial argv, because of the weird
+			   way it is used elsewhere, with the initial term */
+			initial_command = argv;
+		} else {
+			g_strfreev (argv);
+		}
 	}
 	return TRUE;
 }
