@@ -106,13 +106,24 @@ main(int argc, char **argv)
 			       GNORBA_INIT_SERVER_FUNC, &ev);
 	CORBA_exception_free(&ev);
 
+	{
+		CORBA_Object exist;
+		exist = goad_server_activate_with_repo_id(NULL, "IDL:GNOME/Panel:1.0", GOAD_ACTIVATE_EXISTING_ONLY, NULL);
+		if(!CORBA_Object_is_nil(exist, &ev))
+			duplicate = TRUE;
+		else
+			CORBA_Object_release(exist, &ev);
+	}
+
 	duplicate = (panel_corba_gtk_init(orb) == -4);
 
 	client = gnome_master_client ();
 
+#if 0
 	if (! duplicate && 
-	    (gnome_client_get_flags(client) & GNOME_CLIENT_IS_CONNECTED))
-		duplicate = ! gnome_startup_acquire_token("GNOME_PANEL", gnome_client_get_id(client));
+	    (gnome_client_get_flags(client) & GNOME_CLIENT_IS_CONNECTED)) {
+	}
+#endif
 
 	gnome_client_set_restart_style (client, duplicate ? GNOME_RESTART_NEVER : GNOME_RESTART_IMMEDIATELY);
 
@@ -128,9 +139,16 @@ main(int argc, char **argv)
 	}
 	gnome_client_set_priority(client,40);
 
+	/* Since we are implementing only a single session, that
+	 * either can be saved by the user on exit, or not saved,
+	 * it is most natural if we make the saved state global,
+	 * not per-session
+	 */
+#ifdef PER_SESSION_CONFIGURATION
 	if (gnome_client_get_flags(client) & GNOME_CLIENT_RESTORED)
 		old_panel_cfg_path = g_strdup (gnome_client_get_config_prefix (client));
 	else
+#endif /* PER_SESSION_CONFIGURATION */
 		old_panel_cfg_path = g_strdup ("/panel.d/default/");
 
 	gnome_client_set_global_config_prefix (client, "/panel.d/Session/");
